function cm = featdisplay(X,sat,num)
%cm=featdisplay(X,sat,num)
% Display matrix X in color levels after squashing/rescaling.
% Return colormap cm
% Optional: 
% sat -- saturation
% -1 no saturation, zero is mapped to center of map, maximum span
% 0 scaled to full colormap span (zero anywhere)
% 1 saturate to try to map zero to center
% num -- number of colormap levels

% Isabelle Guyon -- January 2000 -- isabelle@clopinet.com

if nargin<2, sat=-1; end
if nargin<3, num=256; end

figure;

if sat==0
   image(X,'CDataMapping', 'scaled');
elseif sat==1
	m=min(min(X));
	M=max(max(X));
	T=min(abs(m),abs(M))/2;
   X=T*tanh(X/T);
   image(X,'CDataMapping', 'scaled');
elseif sat==2 % add scaling min max values of -1 and 1
   X=[X,[-1.05;1.05*ones(size(X,1)-1,1)]];
   image(X,'CDataMapping', 'scaled'); 
elseif sat==3 % add scaling min max values of -.3 and .3
   X=[X,[-.3;.3*ones(size(X,1)-1,1)]];
   image(X,'CDataMapping', 'scaled'); 
elseif sat==4 % add scaling min max values of -.3 and .3
   X=[X,[-.2;.2*ones(size(X,1)-1,1)]];
   image(X,'CDataMapping', 'scaled');  
else % sat==-1
   m=min(min(X));
	M=max(max(X));
   T=max(abs(m),abs(M));
   Y=((X/T)+1)/2;
	Y = uint8(Y*(num-1));
   image(Y);
end

% Create a colormap
x=1:(num/2);
b=[1-exp(-x/(num/8)),exp(-x/(num/8))];
y=(num/2):-1:1;
r=[exp(-y/(num/8)),1-exp(-y/(num/8))];
g=[exp(-y/(num/8)),exp(-x/(num/8))];
%plot(1:num,r,'r-',1:num,g,'g-',1:num,b,'b');
cm=[r',g',b'];
colormap(cm);
if sat~=-1, colorbar; end